summaryrefslogtreecommitdiffstats
path: root/content/port
diff options
context:
space:
mode:
authordarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-01 11:11:22 +0000
committerdarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-01 11:11:22 +0000
commitdc293a7a4addd6d8b93194588a932b1249739914 (patch)
tree273bbf4d77409f6eb4fdf25681416e9de765bdd8 /content/port
parent33539eced948a06b9e8dd7891eadeb515921955a (diff)
downloadchromium_src-dc293a7a4addd6d8b93194588a932b1249739914.zip
chromium_src-dc293a7a4addd6d8b93194588a932b1249739914.tar.gz
chromium_src-dc293a7a4addd6d8b93194588a932b1249739914.tar.bz2
Move WebDropData to content::DropData and split off conversion function.
The WebKit::WebDragData constructor is now provided by DropDataBuilder, which lives in content/renderer/. R=jam@chromium.org TBR=cevans@chromium.org BUG=237267 Review URL: https://chromiumcodereview.appspot.com/18281002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@209408 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/port')
-rw-r--r--content/port/browser/render_view_host_delegate_view.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/content/port/browser/render_view_host_delegate_view.h b/content/port/browser/render_view_host_delegate_view.h
index 8b7b953..375b867 100644
--- a/content/port/browser/render_view_host_delegate_view.h
+++ b/content/port/browser/render_view_host_delegate_view.h
@@ -13,7 +13,6 @@
#include "third_party/WebKit/public/web/WebDragOperation.h"
class SkBitmap;
-struct WebDropData;
struct WebMenuItem;
namespace gfx {
@@ -25,6 +24,7 @@ class Vector2d;
namespace content {
struct ContextMenuParams;
+struct DropData;
// This class provides a way for the RenderViewHost to reach out to its
// delegate's view. It only needs to be implemented by embedders if they don't
@@ -48,10 +48,10 @@ class CONTENT_EXPORT RenderViewHostDelegateView {
// The user started dragging content of the specified type within the
// RenderView. Contextual information about the dragged content is supplied
// by WebDropData. If the delegate's view cannot start the drag for /any/
// reason, it must inform the renderer that the drag has ended; otherwise,
// this results in bugs like http://crbug.com/157134.
- virtual void StartDragging(const WebDropData& drop_data,
+ virtual void StartDragging(const DropData& drop_data,
WebKit::WebDragOperationsMask allowed_ops,
const gfx::ImageSkia& image,
const gfx::Vector2d& image_offset,
@@ -48,10 +48,10 @@ class CONTENT_EXPORT RenderViewHostDelegateView {
// The user started dragging content of the specified type within the
// RenderView. Contextual information about the dragged content is supplied
- // by WebDropData. If the delegate's view cannot start the drag for /any/
+ // by DropData. If the delegate's view cannot start the drag for /any/
// reason, it must inform the renderer that the drag has ended; otherwise,
// this results in bugs like http://crbug.com/157134.